@@ -352,11 +352,11 @@ class Error(Exception):
 
 
 if __name__ == '__main__':
-    connection = connect(host="localhost",
-                         port=9000,
+    connection = connect(host="100.24.100.145",
+                         port=9002,
                          scheme="e6xdb",
                          username="admin",
-                         database="./input/tpcds_330mb",
+                         database="s3a://e6x-tpcds-spark/parquet330mb",
                          auth=None,
                          configuration=None,
                          kerberos_service_name=None,
